==> openshift-model-hive-5.12.3-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterPoolBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterPoolBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterPool,io.fabric8.openshift.api.model.hive.v1.ClusterPoolBuilder>{
  public ClusterPoolBuilder() {
    this(false);
  }
  public ClusterPoolBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterPool(), validationEnabled);
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterPool(), validationEnabled);
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPool instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPool instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPool instance) {
    this(instance,false);
  }
  public ClusterPoolBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPool instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterPoolFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterPool build() {
    ClusterPool buildable = new ClusterPool(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPoolBuilder that = (ClusterPoolBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterPoolBuilder extends ClusterPoolFluentImpl<ClusterPoolBuilder> implements VisitableBuilder<ClusterPool,ClusterPoolBuilder>{
  public ClusterPoolBuilder() {
    this(false);
  }
  public ClusterPoolBuilder(Boolean validationEnabled) {
    this(new ClusterPool(), validationEnabled);
  }
  public ClusterPoolBuilder(ClusterPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolBuilder(ClusterPoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterPool(), validationEnabled);
  }
  public ClusterPoolBuilder(ClusterPoolFluent<?> fluent,ClusterPool instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolBuilder(ClusterPoolFluent<?> fluent,ClusterPool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolBuilder(ClusterPool instance) {
    this(instance,false);
  }
  public ClusterPoolBuilder(ClusterPool instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterPoolFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterPool build() {
    ClusterPool buildable = new ClusterPool(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
